@@ -6,8 +6,8 @@ from komolibs.aws.s3.s3_base import S3Base
 
 
 class Download(S3Base):
-    def __init__(self, access_key: str, access_secret: str, region: str):
-        super().__init__(access_key, access_secret, region)
+    def __init__(self):
+        super().__init__()
 
     def download(self, bucket: str, file_name: str) -> Any:
         try:
